import { MaybeUncommittedBlocksDto, UserPatchDto, MaybeUncommittedWalkthroughDto, WalkthroughPatchDto, UncommittedInviteDto, CheckoutSessionDto, UncommittedBillingPortalSessionDto, ContactRequestDto, CreateUserIntentDto } from '@annotate-dev/dtos';

export declare class Api {
    private readonly authToken?;
    constructor(authToken?: string);
    getWalkthrough(walkthroughId: string): Promise<{
        id: string;
        workspaceName: string;
        draftVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        };
        publishedVersion: ({
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        } & {
            slug: string;
        }) | null;
        createdAt: string;
    }>;
    upsertWalkthrough(walkthrough: MaybeUncommittedWalkthroughDto): Promise<{
        id: string;
        workspaceName: string;
        draftVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        };
        publishedVersion: ({
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        } & {
            slug: string;
        }) | null;
        createdAt: string;
    }>;
    getBlocksForWalkthrough(walkthroughId: string, version: "draft" | "published"): Promise<(({
        type: "annotation";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
        codeFileId: string;
        from: number;
        to: number;
    } & {
        createdAt: string;
    }) | ({
        type: "divider";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    }) | ({
        type: "note";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    }))[]>;
    syncBlocksForWalkthrough(walkthroughId: string, blocks: MaybeUncommittedBlocksDto): Promise<(({
        type: "annotation";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
        codeFileId: string;
        from: number;
        to: number;
    } & {
        createdAt: string;
    }) | ({
        type: "divider";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    }) | ({
        type: "note";
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    }))[]>;
    getCodeFilesForWalkthrough(walkthroughId: string, version: "draft" | "published"): Promise<({
        name: string;
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    })[]>;
    syncCodeFilesForWalkthrough(walkthroughId: string, codeFiles: MaybeUncommittedBlocksDto): Promise<({
        name: string;
        id: string;
        content: string;
        walkthroughId: string;
        walkthroughVersionType: "draft" | "published";
    } & {
        createdAt: string;
    })[]>;
    publishWalkthrough(walkthroughId: string): Promise<{
        id: string;
        workspaceName: string;
        draftVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        };
        publishedVersion: ({
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        } & {
            slug: string;
        }) | null;
        createdAt: string;
    }>;
    createUserSessionFromEmailAndPassword(email: string, password: string): Promise<{
        id: string;
        createdAt: string;
        token: string;
        userId: string;
        expiredAt: string;
    }>;
    exchangeGoogleOidcCodeForUserSession(oidcToken: string): Promise<{
        id: string;
        createdAt: string;
        token: string;
        userId: string;
        expiredAt: string;
    }>;
    getUser(): Promise<{
        name: string | null;
        id: string;
        email: string;
    }>;
    getWorkspaceByName(workspaceName: string): Promise<{
        name: string;
    }>;
    updateAuthedUser(patch: UserPatchDto): Promise<{
        name: string | null;
        id: string;
        email: string;
    }>;
    createWorkspace(workspace: {
        id: string;
        name: string;
    }): Promise<{
        name: string;
    }>;
    patchWalkthrough(walkthroughId: string, patch: WalkthroughPatchDto): Promise<{
        id: string;
        workspaceName: string;
        draftVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        };
        publishedVersion: ({
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        } & {
            slug: string;
        }) | null;
        createdAt: string;
    }>;
    getWalkthroughsForWorkspace(workspaceName: string): Promise<({
        id: string;
        workspaceName: string;
        draftVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        };
        publishedVersion: {
            title: string;
            createdAt: string;
            description: string;
            author: {
                name: string | null;
                id: string;
            };
            updatedAt: string;
        } | null;
    } & {
        createdAt: string;
        publishedVersion: {
            slug: string;
        } | null;
    })[]>;
    getMemberships(): Promise<{
        createdAt: string;
        workspaceName: string;
        user: {
            name: string | null;
            id: string;
            email: string;
        };
    }[]>;
    getMembershipsForWorkspace(workspaceName: string): Promise<{
        createdAt: string;
        workspaceName: string;
        user: {
            name: string | null;
            id: string;
            email: string;
        };
    }[]>;
    getSubscriptionForWorkspace(workspaceName: string): Promise<{
        id: string;
        status: string;
        createdAt: string;
        workspaceName: string;
        updatedAt: string;
    }>;
    getInvitesForWorkspace(workspaceName: string): Promise<{
        id: string;
        email: string;
        createdAt: string;
        workspaceName: string;
        inviter: {
            name: string | null;
            id: string;
            email: string;
        };
        redeemer: {
            name: string | null;
            id: string;
            email: string;
        } | null;
        expiresAt: string | null;
        sentAt: string;
    }[]>;
    sendOrResendInvite(invite: UncommittedInviteDto): Promise<{
        id: string;
        email: string;
        createdAt: string;
        workspaceName: string;
        inviter: {
            name: string | null;
            id: string;
            email: string;
        };
        redeemer: {
            name: string | null;
            id: string;
            email: string;
        } | null;
        expiresAt: string | null;
        sentAt: string;
    }>;
    getInvite(inviteId: string): Promise<{
        id: string;
        email: string;
        createdAt: string;
        workspaceName: string;
        inviter: {
            name: string | null;
            id: string;
            email: string;
        };
        redeemer: {
            name: string | null;
            id: string;
            email: string;
        } | null;
        expiresAt: string | null;
        sentAt: string;
    }>;
    redeemInvite(inviteId: string): Promise<{
        createdAt: string;
        workspaceName: string;
        user: {
            name: string | null;
            id: string;
            email: string;
        };
    }>;
    createCheckoutSession(checkoutSession: CheckoutSessionDto): Promise<{
        workspaceName: string;
        successUrl: string;
        cancelUrl: string;
        checkoutUrl: string | null;
    }>;
    createBillingPortalSession(uncommittedBillgingPortalSession: UncommittedBillingPortalSessionDto): Promise<{
        url: string;
        workspaceName: string;
        returnUrl: string;
    }>;
    createContactRequest(contactRequest: ContactRequestDto): Promise<{
        emailAddress: string;
        subject: string;
        message: string;
    }>;
    deleteUserSession(): Promise<{
        id: string;
        createdAt: string;
        token: string;
        userId: string;
        expiredAt: string;
    }>;
    createUser(createUserIntent: CreateUserIntentDto): Promise<{
        name: string | null;
        id: string;
        email: string;
    }>;
    private get;
    private post;
    private put;
    private patch;
    private delete_;
    private makeApiCall;
}
export declare class ApiError extends Error {
    readonly httpStatus: number;
    constructor(message: string, httpStatus: number);
}
